@@ -22,6 +22,11 @@ if NEW_TYPING:
     from typing import (
         Generic, Callable, Union, TypeVar, ClassVar, Tuple, _GenericAlias, ForwardRef
     )
+    try:
+        from typing import _SpecialGenericAlias
+        _GenericAlias = (_GenericAlias, _SpecialGenericAlias)
+    except:
+        pass
     from typing_extensions import Literal
 else:
     from typing import (
@@ -428,6 +433,7 @@ def get_args(tp, evaluate=None):
         if evaluate is not None and not evaluate:
             raise ValueError('evaluate can only be True in Python >= 3.7')
         if isinstance(tp, _GenericAlias):
+            if not hasattr(tp, "__args__"): return ()
             res = tp.__args__
             if get_origin(tp) is collections.abc.Callable and res[0] is not Ellipsis:
                 res = (list(res[:-1]), res[-1])
